=======
Credits
=======

* Romain Lopez <romain_lopez@berkeley.edu>
* Jeffrey Regier <jregier@eecs.berkeley.edu>
* Chenling Antelope <chenlingantelope@berkeley.edu>
* Adam Gayoso <adamgayoso@berkeley.edu>
* Maxime Langevin <maxime.langevin@polytechnique.edu>
* Edouard Mehlman <edouard.mehlman@polytechnique.edu>
* Achille Nazaret <achille.nazaret@polytechnique.edu>
* Gabriel Misrachi <gabriel.misrachi@polytechnique.edu>
* Oscar Clivio <oscar.clivio@eleves.enpc.fr>
* Pierre Boyeau <pierre.boyeau@eleves.enpc.fr>
* Yining Liu <lyining@berkeley.edu>
* Jules Samaran <jules.samaran@mines-paristech.fr>

